summaryrefslogtreecommitdiff
path: root/www/crm/wp-includes/js/wp-a11y.js
diff options
context:
space:
mode:
authorYaco <franco@reevo.org>2019-10-04 16:03:20 -0300
committerYaco <franco@reevo.org>2019-10-04 16:03:20 -0300
commitac6bedd68a70d744a927494351100e6bfabfe14e (patch)
tree7a9a7967a6244008edbc27055b205d936cb45b02 /www/crm/wp-includes/js/wp-a11y.js
parentb25b94b8b0aacab5a5a38bb107201c7f92c083ab (diff)
Actualiza WP a 5.2.3
Diffstat (limited to 'www/crm/wp-includes/js/wp-a11y.js')
-rw-r--r--www/crm/wp-includes/js/wp-a11y.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/www/crm/wp-includes/js/wp-a11y.js b/www/crm/wp-includes/js/wp-a11y.js
index 503c6214..648b629d 100644
--- a/www/crm/wp-includes/js/wp-a11y.js
+++ b/www/crm/wp-includes/js/wp-a11y.js
@@ -27,8 +27,8 @@ window.wp = window.wp || {};
// Clear previous messages to allow repeated strings being read out.
clear();
- // Ensure only text is sent to screen readers.
- message = $( '<p>' ).html( message ).text();
+ // Remove HTML tags, ensuring only text is sent to screen readers.
+ message = wp.sanitize.stripTagsAndEncodeText( message );
/*
* Safari 10+VoiceOver don't announce repeated, identical strings. We use